package br.com.bookstore.integracao;

import java.util.List;

import br.com.bookstore.cliente.Usuario;

public interface ClienteDao {

	/**
	 * Realiza o cadastro de um novo cliente. O cadastro no deve ser permitido
	 * caso o cliente esteja marcado com o perfil de administrador. Da mesma forma,
	 * o cadastro tambm no deve ser permitido caso j exista um cliente com o mesmo
	 * CPF cadastrado na base de dados da aplicao.
	 * 
	 * @param cliente o Cliente a ser cadastrado.
	 * @throws ClienteException Caso o cliente a ser cadastrado j exista na base de dados, possua alguma
	 * 							informao invlida, ou esteja com o perfil de administrador configurado.
	 */
	public void insertCliente( Usuario cliente );
	
	/**
	 * Exclui um cliente da base de dados da aplicao. No deve ser possvel, via aplicao,
	 * remover um usurio, cujo perfil seja administrador. 
	 * 
	 * @param cliente O cliente a ser removido
	 * @throws ClienteException Caso o cliente a ser removido no exista, ou possua o perfil de administrador.
	 * @throws Exception 
	 */
	public void deleteCliente( Usuario cliente ) throws Exception;
	
	/**
	 * Permite modificar as informaes cadastrais de um cliente. No deve ser possvel alterar o CPF
	 * do cliente, nem mudar o seu perfil. As informaes atuais do cliente sero subistitudas pelas 
	 * informaes fornecidas atravs do objeto passado como parmetro.
	 * 
	 * @param cliente O cliente cujas informaes sero modificadas.
	 * @throws ClienteException Caso existam restries nos dados fornecidos atravs do novo objeto passado
	 * 							como parmetro ou o cliente a ser modificado no exista nas bases de dados.
	 */
	public void updateCliente( Usuario cliente );
	
	/**
	 * Obtm uma lista com todos os clientes cadastrados na aplicao. Esta lista no deve conter usurios
	 * marcados como administradores.
	 * 
	 * @return Uma lista com todos os clientes cadastrados, ou uma lista vazia, caso no exista nenhum
	 * 			cliente cadastrado.
	 */
	public List<Usuario> searchClientes();

	/**
	 * Obtm o cliente representado pelo CPF passado como parmetro. Usurios que possuem o perfil
	 * de administrador no so visveis a esta chamada.
	 * 
	 * @param cpf o CPF usado para recuperar o cliente especfico.
	 * @return o cliente cujo CPF foi passado como parmetro, ou null, caso no exista cliente cadastrado
	 * 			com o CPF em questo.
	 * @throws Exception 
	 */
	public Usuario searchCliente( String cpf ) throws Exception; 
	
	public Usuario serachClienteId(Integer id );

}
